@@ -2,11 +2,9 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
-
-from __future__ import absolute_import
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 
 # get version numbers, license, and long description
 try:
@@ -24,7 +22,7 @@ __doc__ = """
 __license__ = """
 """ + __license__
 
-from .dill import dump, dumps, load, loads, dump_session, load_session, \
+from ._dill import dump, dumps, load, loads, dump_session, load_session, \
     Pickler, Unpickler, register, copy, pickle, pickles, check, \
     HIGHEST_PROTOCOL, DEFAULT_PROTOCOL, PicklingError, UnpicklingError, \
     HANDLE_FMODE, CONTENTS_FMODE, FILE_FMODE
@@ -37,9 +35,12 @@ from .settings import settings
 detect.trace(False)
 
 try:
-    from imp import reload
+    from importlib import reload
 except ImportError:
-    pass
+    try:
+        from imp import reload
+    except ImportError:
+        pass
 
 # put the objects in order, if possible
 try:
@@ -59,7 +60,20 @@ objects = odict()
 from . import objtypes as types
 
 def load_types(pickleable=True, unpickleable=True):
-    """load pickleable and/or unpickleable types to dill.types"""
+    """load pickleable and/or unpickleable types to ``dill.types``
+
+    ``dill.types`` is meant to mimic the ``types`` module, providing a
+    registry of object types.  By default, the module is empty (for import
+    speed purposes). Use the ``load_types`` function to load selected object
+    types to the ``dill.types`` module.
+
+    Args:
+        pickleable (bool, default=True): if True, load pickleable types.
+        unpickleable (bool, default=True): if True, load unpickleable types.
+
+    Returns:
+        None
+    """
     # local import of dill.objects
     from . import _objects
     if pickleable:
@@ -79,8 +93,19 @@ def load_types(pickleable=True, unpickleable=True):
     reload(types)
 
 def extend(use_dill=True):
-    '''add (or remove) dill types to/from pickle'''
-    from .dill import _revert_extension, _extend
+    '''add (or remove) dill types to/from the pickle registry
+
+    by default, ``dill`` populates its types to ``pickle.Pickler.dispatch``.
+    Thus, all ``dill`` types are available upon calling ``'import pickle'``.
+    To drop all ``dill`` types from the ``pickle`` dispatch, *use_dill=False*.
+
+    Args:
+        use_dill (bool, default=True): if True, extend the dispatch table.
+
+    Returns:
+        None
+    '''
+    from ._dill import _revert_extension, _extend
     if use_dill: _extend()
     else: _revert_extension()
     return
@@ -97,7 +122,6 @@ def citation():
     print (__doc__[-501:-123])
     return
 
-del absolute_import
 del odict
 
 # end of file
