@@ -2,20 +2,23 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 """
 Methods for detecting objects leading to pickling failures.
 """
 
-from __future__ import absolute_import, with_statement
 import dis
 from inspect import ismethod, isfunction, istraceback, isframe, iscode
 from .pointers import parent, reference, at, parents, children
 
-from .dill import _trace as trace
-from .dill import PY3
+from ._dill import _trace as trace
+from ._dill import PY3
+
+__all__ = ['baditems','badobjects','badtypes','code','errors','freevars',
+           'getmodule','globalvars','nestedcode','nestedglobals','outermost',
+           'referredglobals','referrednested','trace','varnames']
 
 def getmodule(object, _filename=None, force=False):
     """get the module of the object"""
@@ -301,7 +304,5 @@ def errors(obj, depth=0, exact=False, safe=False):
             _dict[attr] = errors(_attr,depth-1,exact,safe)
     return _dict
 
-del absolute_import, with_statement
-
 
 # EOF
