@@ -2,9 +2,9 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 """
 all Python Standard Library object types (currently: CH 1-15 @ 2.7)
 and some other common object types (i.e. numpy.ndarray)
@@ -12,8 +12,6 @@ and some other common object types (i.e. numpy.ndarray)
 to load more objects and types, use dill.load_types()
 """
 
-from __future__ import absolute_import
-
 # non-local import of dill.objects
 from dill import objects
 for _type in objects.keys():
@@ -24,5 +22,3 @@ try:
     del _type
 except NameError:
     pass
-
-del absolute_import
