@@ -2,18 +2,17 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 
-from __future__ import absolute_import
 __all__ = ['parent', 'reference', 'at', 'parents', 'children']
 
 import gc
 import sys
 
-from .dill import _proxy_helper as reference
-from .dill import _locate_object as at
+from ._dill import _proxy_helper as reference
+from ._dill import _locate_object as at
 
 def parent(obj, objtype, ignore=()):
     """
