@@ -2,9 +2,9 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 #
 # inspired by inspect.py from Python-2.7.6
 # inspect.py author: 'Ka-Ping Yee <ping@lfw.org>'
@@ -18,7 +18,6 @@ as well as provide access to source code for objects defined
 in a file.
 """
 
-from __future__ import absolute_import
 __all__ = ['findsource', 'getsourcelines', 'getsource', 'indent', 'outdent', \
            '_wrap', 'dumpsource', 'getname', '_namespace', 'getimport', \
            '_importable', 'importable','isdynamic', 'isfrommain']
@@ -29,7 +28,7 @@ from tokenize import TokenError
 from inspect import ismodule, isclass, ismethod, isfunction, istraceback
 from inspect import isframe, iscode, getfile, getmodule, getsourcefile
 from inspect import getblock, indentsize, isbuiltin
-from .dill import PY3
+from ._dill import PY3
 
 def isfrommain(obj):
     "check if object was built in __main__"
@@ -50,8 +49,8 @@ def isdynamic(obj):
 
 def _matchlambda(func, line):
     """check if lambda object 'func' matches raw line of code 'line'"""
-    from dill.detect import code as getcode
-    from dill.detect import freevars, globalvars, varnames
+    from .detect import code as getcode
+    from .detect import freevars, globalvars, varnames
     dummy = lambda : '__this_is_a_big_dummy_function__'
     # process the line (removing leading whitespace, etc)
     lhs,rhs = line.split('lambda ',1)[-1].split(":", 1) #FIXME: if !1 inputs
@@ -508,7 +507,7 @@ def _wrap(f):
     """ encapsulate a function and it's __import__ """
     def func(*args, **kwds):
         try:
-            #_ = eval(getsource(f, force=True)) #FIXME: safer, but not as robust
+            # _ = eval(getsource(f, force=True)) #XXX: safer but less robust
             exec getimportable(f, alias='_') in %s, %s
         except:
             raise ImportError('cannot import name ' + f.__name__)
@@ -522,7 +521,7 @@ def _wrap(f):
     """ encapsulate a function and it's __import__ """
     def func(*args, **kwds):
         try:
-            #_ = eval(getsource(f, force=True)) #FIXME: safer, but not as robust
+            # _ = eval(getsource(f, force=True)) #XXX: safer but less robust
             exec(getimportable(f, alias='_'), %s, %s)
         except:
             raise ImportError('cannot import name ' + f.__name__)
@@ -720,7 +719,7 @@ def getimport(obj, alias='', verify=True, builtin=False, enclosing=False):
     If alias is provided, then rename the object on import.
     """
     if enclosing:
-        from dill.detect import outermost
+        from .detect import outermost
         _obj = outermost(obj)
         obj = _obj if _obj else obj
     # get the namespace
@@ -826,7 +825,7 @@ def _importable(obj, alias='', source=None, enclosing=False, force=True, \
 def _closuredimport(func, alias='', builtin=False):
     """get import for closured objects; return a dict of 'name' and 'import'"""
     import re
-    from dill.detect import freevars, outermost
+    from .detect import freevars, outermost
     free_vars = freevars(func)
     func_vars = {}
     # split into 'funcs' and 'non-funcs'
@@ -883,7 +882,7 @@ def _closuredsource(func, alias=''):
     #      - pollutes global namespace
     #      - fails if name of freevars are reused
     #      - can unnecessarily duplicate function code
-    from dill.detect import freevars
+    from .detect import freevars
     free_vars = freevars(func)
     func_vars = {}
     # split into 'funcs' and 'non-funcs'
@@ -980,7 +979,7 @@ def importable(obj, alias='', source=None, builtin=True):
             else:
                 src = '\n'.join(_src)
             # get source code of objects referred to by obj in global scope
-            from dill.detect import globalvars
+            from .detect import globalvars
             obj = globalvars(obj) #XXX: don't worry about alias? recurse? etc?
             obj = list(getsource(_obj,name,force=True) for (name,_obj) in obj.items() if not isbuiltin(_obj))
             obj = '\n'.join(obj) if obj else ''
