@@ -2,16 +2,16 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 
 from __future__ import with_statement
 from dill import check
 import sys
 
 from dill.temp import capture
-from dill.dill import PY3
+from dill._dill import PY3
 
 
 #FIXME: this doesn't catch output... it's from the internal call
@@ -48,10 +48,7 @@ def test_protocol():
 
 
 def test_python():
-    if PY3:
-        raise_check(f, python='python3.4')
-    else:
-        raise_check(f, python='python2.7')
+    raise_check(f, python=None)
 
 
 #TODO: test incompatible versions
